@@ -49,6 +49,14 @@ describe Doorkeeper::OpenidConnect, 'configuration' do
       end
       expect(subject.issuer).to eq(value)
     end
+
+    it 'sets the block that is accessible via issuer' do
+      block = proc {}
+      described_class.configure do
+        issuer(&block)
+      end
+      expect(subject.issuer).to eq(block)
+    end
   end
 
   describe 'resource_owner_from_access_token' do
@@ -196,4 +204,28 @@ describe Doorkeeper::OpenidConnect, 'configuration' do
       expect(subject.end_session_endpoint.call).to eq('http://test.host/logout')
     end
   end
+
+  describe 'discovery_url_options' do
+    it 'defaults to empty hash' do
+      expect(subject.discovery_url_options.call).to be_kind_of(Hash)
+      expect(subject.discovery_url_options.call).to be_empty
+    end
+
+    it 'can be set to other hosts' do
+      Doorkeeper::OpenidConnect.configure do
+        discovery_url_options do |request|
+          {
+            authorization: { host: 'alternate-authorization-host' },
+            token: { host: 'alternate-token-host' },
+            revocation: { host: 'alternate-revocation-host' },
+            introspection: { host: 'alternate-introspection-host' },
+            userinfo: { host: 'alternate-userinfo-host' },
+            jwks: { host: 'alternate-jwks-host' }
+          }
+        end
+      end
+
+      expect(subject.discovery_url_options.call[:authorization]).to eq(host: 'alternate-authorization-host')
+    end
+  end
 end
